@@ -1,4 +1,4 @@
-# $Id: lexer.py 2013 2005-12-31 03:19:39Z zzzeek $
+# $Id: lexer.py 2039 2006-02-05 06:58:40Z zzzeek $
 # lexer.py - template parsing routines for Myghty
 # Copyright (C) 2004, 2005 Michael Bayer mike_mp@zzzcomputing.com
 # Original Perl code and documentation copyright (c) 1998-2003 by Jonathan Swartz. 
@@ -200,11 +200,9 @@ class Lexer:
 
         if self.current.in_def or self.current.in_method:
             type = self.current.block_type
-                
-            if not self.current.ending.match(end):
+            if not isinstance(end, str) or not self.current.ending.match(end):
                 block_name = self.current.block_name
-                self.raise_syntax_error("no </%%%s> tag for <%%%s %s> block" % (type, type, block_name))
-
+                self.raise_syntax_error("no closing </%%%s> tag for <%%%s %s> block" % (type, type, block_name))
 
 
     def match_block(self):
