@@ -1,4 +1,4 @@
-# $Id: request.py 2028 2006-01-16 23:39:04Z zzzeek $
+# $Id: request.py 2053 2006-03-02 16:58:25Z zzzeek $
 # request.py - handles component calls for Myghty templates
 # Copyright (C) 2004, 2005 Michael Bayer mike_mp@zzzcomputing.com
 # Original Perl code and documentation copyright (c) 1998-2003 by Jonathan Swartz.
@@ -779,7 +779,7 @@ class Request(object):
                 args = {}
 
             self.clear_buffer()
-            req = self.create_subrequest(path, request_args = args)
+            req = self.create_subrequest(path, resolver_context = self.resolver_context, request_args = args)
             req.execute()
             raise exception.AbortRequest()
         
@@ -814,11 +814,13 @@ class Request(object):
         buffer.seek(0)
         return buffer.read()
         
-    def closure_with_content(self, func, content, args):
+    def closure_with_content(self, func, content=None, args=None):
         """given a function, will execute it with the given arguments, after pushing
         the given content function onto the call stack via a new StackFrame, enabling
         the function to call it via the content() method."""
         frame = Request.StackFrame(self, func, args, self.base_component, content, False)
+        if args is None:
+            args = {}
         self.execution_stack.append(frame)
         try:
             func(**args)
